@@ -1,28 +1,25 @@
 """
-Defines classes for path effects. The path effects are supported in
-:class:`~matplotlib.text.Text`, :class:`~matplotlib.lines.Line2D`
-and :class:`~matplotlib.patches.Patch`.
+Defines classes for path effects. The path effects are supported in `~.Text`,
+`~.Line2D` and `~.Patch`.
+
+.. seealso::
+   :doc:`/tutorials/advanced/patheffects_guide`
 """
 
-from __future__ import (absolute_import, division, print_function,
-                        unicode_literals)
-
-from matplotlib.externals import six
-
 from matplotlib.backend_bases import RendererBase
-import matplotlib.transforms as mtransforms
-from matplotlib.colors import colorConverter
-import matplotlib.patches as mpatches
+from matplotlib import colors as mcolors
+from matplotlib import patches as mpatches
+from matplotlib import transforms as mtransforms
 
 
-class AbstractPathEffect(object):
+class AbstractPathEffect:
     """
     A base class for path effects.
 
     Subclasses should override the ``draw_path`` method to add effect
     functionality.
-
     """
+
     def __init__(self, offset=(0., 0.)):
         """
         Parameters
@@ -31,14 +28,11 @@ class AbstractPathEffect(object):
             The offset to apply to the path, measured in points.
         """
         self._offset = offset
-        self._offset_trans = mtransforms.Affine2D()
 
-    def _offset_transform(self, renderer, transform):
+    def _offset_transform(self, renderer):
         """Apply the offset to the given transform."""
-        offset_x = renderer.points_to_pixels(self._offset[0])
-        offset_y = renderer.points_to_pixels(self._offset[1])
-        return transform + self._offset_trans.clear().translate(offset_x,
-                                                                offset_y)
+        return mtransforms.Affine2D().translate(
+            *map(renderer.points_to_pixels, self._offset))
 
     def _update_gc(self, gc, new_gc_dict):
         """
@@ -53,9 +47,9 @@ class AbstractPathEffect(object):
         if dashes:
             gc.set_dashes(**dashes)
 
-        for k, v in six.iteritems(new_gc_dict):
+        for k, v in new_gc_dict.items():
             set_method = getattr(gc, 'set_' + k, None)
-            if set_method is None or not six.callable(set_method):
+            if not callable(set_method):
                 raise AttributeError('Unknown property {0}'.format(k))
             set_method(v)
         return gc
@@ -84,23 +78,20 @@ class PathEffectRenderer(RendererBase):
         Not all methods have been overridden on this RendererBase subclass.
         It may be necessary to add further methods to extend the PathEffects
         capabilities further.
-
     """
+
     def __init__(self, path_effects, renderer):
         """
         Parameters
         ----------
         path_effects : iterable of :class:`AbstractPathEffect`
             The path effects which this renderer represents.
-        renderer : :class:`matplotlib.backend_bases.RendererBase` instance
+        renderer : `matplotlib.backend_bases.RendererBase` subclass
 
         """
         self._path_effects = path_effects
         self._renderer = renderer
 
-    def new_gc(self):
-        return self._renderer.new_gc()
-
     def copy_with_path_effect(self, path_effects):
         return self.__class__(path_effects, self._renderer)
 
@@ -109,8 +100,8 @@ class PathEffectRenderer(RendererBase):
             path_effect.draw_path(self._renderer, gc, tpath, affine,
                                   rgbFace)
 
-    def draw_markers(self, gc, marker_path, marker_trans, path, *args,
-                             **kwargs):
+    def draw_markers(
+            self, gc, marker_path, marker_trans, path, *args, **kwargs):
         # We do a little shimmy so that all markers are drawn for each path
         # effect in turn. Essentially, we induce recursion (depth 1) which is
         # terminated once we have just a single path effect to work with.
@@ -147,9 +138,6 @@ class PathEffectRenderer(RendererBase):
             renderer.draw_path_collection(gc, master_transform, paths,
                                           *args, **kwargs)
 
-    def points_to_pixels(self, points):
-        return self._renderer.points_to_pixels(points)
-
     def _draw_text_as_path(self, gc, x, y, s, prop, angle, ismath):
         # Implements the naive text drawing as is found in RendererBase.
         path, transform = self._get_text_path_transform(x, y, s, prop,
@@ -159,7 +147,8 @@ class PathEffectRenderer(RendererBase):
         self.draw_path(gc, path, transform, rgbFace=color)
 
     def __getattribute__(self, name):
-        if name in ['_text2path', 'flipy', 'height', 'width']:
+        if name in ['flipy', 'get_canvas_width_height', 'new_gc',
+                    'points_to_pixels', '_text2path', 'height', 'width']:
             return getattr(self._renderer, name)
         else:
             return object.__getattribute__(self, name)
@@ -172,48 +161,66 @@ class Normal(AbstractPathEffect):
     The Normal PathEffect's sole purpose is to draw the original artist with
     no special path effect.
     """
-    pass
+
+
+def _subclass_with_normal(effect_class):
+    """
+    Create a PathEffect class combining *effect_class* and a normal draw.
+    """
+
+    class withEffect(effect_class):
+        def draw_path(self, renderer, gc, tpath, affine, rgbFace):
+            super().draw_path(renderer, gc, tpath, affine, rgbFace)
+            renderer.draw_path(gc, tpath, affine, rgbFace)
+
+    withEffect.__name__ = f"with{effect_class.__name__}"
+    withEffect.__qualname__ = f"with{effect_class.__name__}"
+    withEffect.__doc__ = f"""
+    A shortcut PathEffect for applying `.{effect_class.__name__}` and then
+    drawing the original Artist.
+
+    With this class you can use ::
+
+        artist.set_path_effects([path_effects.with{effect_class.__name__}()])
+
+    as a shortcut for ::
+
+        artist.set_path_effects([path_effects.{effect_class.__name__}(),
+                                 path_effects.Normal()])
+    """
+    # Docstring inheritance doesn't work for locally-defined subclasses.
+    withEffect.draw_path.__doc__ = effect_class.draw_path.__doc__
+    return withEffect
 
 
 class Stroke(AbstractPathEffect):
     """A line based PathEffect which re-draws a stroke."""
+
     def __init__(self, offset=(0, 0), **kwargs):
         """
         The path will be stroked with its gc updated with the given
         keyword arguments, i.e., the keyword arguments should be valid
         gc parameter values.
         """
-        super(Stroke, self).__init__(offset)
+        super().__init__(offset)
         self._gc = kwargs
 
     def draw_path(self, renderer, gc, tpath, affine, rgbFace):
-        """
-        draw the path with updated gc.
-        """
-        # Do not modify the input! Use copy instead.
-
-        gc0 = renderer.new_gc()
+        """Draw the path with updated gc."""
+        gc0 = renderer.new_gc()  # Don't modify gc, but a copy!
         gc0.copy_properties(gc)
-
         gc0 = self._update_gc(gc0, self._gc)
-        trans = self._offset_transform(renderer, affine)
-        renderer.draw_path(gc0, tpath, trans, rgbFace)
+        renderer.draw_path(
+            gc0, tpath, affine + self._offset_transform(renderer), rgbFace)
         gc0.restore()
 
 
-class withStroke(Stroke):
-    """
-    Adds a simple :class:`Stroke` and then draws the
-    original Artist to avoid needing to call :class:`Normal`.
-
-    """
-    def draw_path(self, renderer, gc, tpath, affine, rgbFace):
-        Stroke.draw_path(self, renderer, gc, tpath, affine, rgbFace)
-        renderer.draw_path(gc, tpath, affine, rgbFace)
+withStroke = _subclass_with_normal(effect_class=Stroke)
 
 
 class SimplePatchShadow(AbstractPathEffect):
     """A simple shadow via a filled patch."""
+
     def __init__(self, offset=(2, -2),
                  shadow_rgbFace=None, alpha=None,
                  rho=0.3, **kwargs):
@@ -224,24 +231,23 @@ class SimplePatchShadow(AbstractPathEffect):
             The offset of the shadow in points.
         shadow_rgbFace : color
             The shadow color.
-        alpha : float
+        alpha : float, default: 0.3
             The alpha transparency of the created shadow patch.
-            Default is 0.3.
             http://matplotlib.1069221.n5.nabble.com/path-effects-question-td27630.html
-        rho : float
+        rho : float, default: 0.3
             A scale factor to apply to the rgbFace color if `shadow_rgbFace`
-            is not specified. Default is 0.3.
+            is not specified.
         **kwargs
             Extra keywords are stored and passed through to
             :meth:`AbstractPathEffect._update_gc`.
 
         """
-        super(SimplePatchShadow, self).__init__(offset)
+        super().__init__(offset)
 
         if shadow_rgbFace is None:
             self._shadow_rgbFace = shadow_rgbFace
         else:
-            self._shadow_rgbFace = colorConverter.to_rgba(shadow_rgbFace)
+            self._shadow_rgbFace = mcolors.to_rgba(shadow_rgbFace)
 
         if alpha is None:
             alpha = 0.3
@@ -252,23 +258,16 @@ class SimplePatchShadow(AbstractPathEffect):
         #: The dictionary of keywords to update the graphics collection with.
         self._gc = kwargs
 
-        #: The offset transform object. The offset isn't calculated yet
-        #: as we don't know how big the figure will be in pixels.
-        self._offset_tran = mtransforms.Affine2D()
-
     def draw_path(self, renderer, gc, tpath, affine, rgbFace):
         """
         Overrides the standard draw_path to add the shadow offset and
         necessary color changes for the shadow.
-
         """
-        # IMPORTANT: Do not modify the input - we copy everything instead.
-        affine0 = self._offset_transform(renderer, affine)
-        gc0 = renderer.new_gc()
+        gc0 = renderer.new_gc()  # Don't modify gc, but a copy!
         gc0.copy_properties(gc)
 
         if self._shadow_rgbFace is None:
-            r,g,b = (rgbFace or (1., 1., 1.))[:3]
+            r, g, b = (rgbFace or (1., 1., 1.))[:3]
             # Scale the colors by a factor to improve the shadow effect.
             shadow_rgbFace = (r * self._rho, g * self._rho, b * self._rho)
         else:
@@ -279,114 +278,98 @@ class SimplePatchShadow(AbstractPathEffect):
         gc0.set_linewidth(0)
 
         gc0 = self._update_gc(gc0, self._gc)
-        renderer.draw_path(gc0, tpath, affine0, shadow_rgbFace)
+        renderer.draw_path(
+            gc0, tpath, affine + self._offset_transform(renderer),
+            shadow_rgbFace)
         gc0.restore()
 
 
-class withSimplePatchShadow(SimplePatchShadow):
-    """
-    Adds a simple :class:`SimplePatchShadow` and then draws the
-    original Artist to avoid needing to call :class:`Normal`.
-
-    """
-    def draw_path(self, renderer, gc, tpath, affine, rgbFace):
-        SimplePatchShadow.draw_path(self, renderer, gc, tpath, affine, rgbFace)
-        renderer.draw_path(gc, tpath, affine, rgbFace)
+withSimplePatchShadow = _subclass_with_normal(effect_class=SimplePatchShadow)
 
 
 class SimpleLineShadow(AbstractPathEffect):
     """A simple shadow via a line."""
-    def __init__(self, offset=(2,-2),
+
+    def __init__(self, offset=(2, -2),
                  shadow_color='k', alpha=0.3, rho=0.3, **kwargs):
         """
         Parameters
         ----------
         offset : pair of floats
             The offset to apply to the path, in points.
-        shadow_color : color
-            The shadow color. Default is black.
+        shadow_color : color, default: 'black'
+            The shadow color.
             A value of ``None`` takes the original artist's color
-            with a scale factor of `rho`.
-        alpha : float
+            with a scale factor of *rho*.
+        alpha : float, default: 0.3
             The alpha transparency of the created shadow patch.
-            Default is 0.3.
-        rho : float
+        rho : float, default: 0.3
             A scale factor to apply to the rgbFace color if `shadow_rgbFace`
-            is ``None``. Default is 0.3.
+            is ``None``.
         **kwargs
             Extra keywords are stored and passed through to
             :meth:`AbstractPathEffect._update_gc`.
-
         """
-        super(SimpleLineShadow, self).__init__(offset)
+        super().__init__(offset)
         if shadow_color is None:
             self._shadow_color = shadow_color
         else:
-            self._shadow_color = colorConverter.to_rgba(shadow_color)
+            self._shadow_color = mcolors.to_rgba(shadow_color)
         self._alpha = alpha
         self._rho = rho
-
         #: The dictionary of keywords to update the graphics collection with.
         self._gc = kwargs
 
-        #: The offset transform object. The offset isn't calculated yet
-        #: as we don't know how big the figure will be in pixels.
-        self._offset_tran = mtransforms.Affine2D()
-
     def draw_path(self, renderer, gc, tpath, affine, rgbFace):
         """
         Overrides the standard draw_path to add the shadow offset and
         necessary color changes for the shadow.
-
         """
-        # IMPORTANT: Do not modify the input - we copy everything instead.
-        affine0 = self._offset_transform(renderer, affine)
-        gc0 = renderer.new_gc()
+        gc0 = renderer.new_gc()  # Don't modify gc, but a copy!
         gc0.copy_properties(gc)
 
         if self._shadow_color is None:
-            r,g,b = (gc0.get_foreground() or (1., 1., 1.))[:3]
+            r, g, b = (gc0.get_foreground() or (1., 1., 1.))[:3]
             # Scale the colors by a factor to improve the shadow effect.
             shadow_rgbFace = (r * self._rho, g * self._rho, b * self._rho)
         else:
             shadow_rgbFace = self._shadow_color
 
-        fill_color = None
-
         gc0.set_foreground(shadow_rgbFace)
         gc0.set_alpha(self._alpha)
-        gc0.set_linestyle("solid")
 
         gc0 = self._update_gc(gc0, self._gc)
-        renderer.draw_path(gc0, tpath, affine0, fill_color)
+        renderer.draw_path(
+            gc0, tpath, affine + self._offset_transform(renderer))
         gc0.restore()
 
 
 class PathPatchEffect(AbstractPathEffect):
     """
-    Draws a :class:`~matplotlib.patches.PathPatch` instance whose Path
-    comes from the original PathEffect artist.
-
+    Draws a `.PathPatch` instance whose Path comes from the original
+    PathEffect artist.
     """
+
     def __init__(self, offset=(0, 0), **kwargs):
         """
         Parameters
         ----------
         offset : pair of floats
             The offset to apply to the path, in points.
-        **kwargs :
+        **kwargs
             All keyword arguments are passed through to the
             :class:`~matplotlib.patches.PathPatch` constructor. The
             properties which cannot be overridden are "path", "clip_box"
             "transform" and "clip_path".
         """
-        super(PathPatchEffect, self).__init__(offset=offset)
+        super().__init__(offset=offset)
         self.patch = mpatches.PathPatch([], **kwargs)
 
     def draw_path(self, renderer, gc, tpath, affine, rgbFace):
-        affine = self._offset_transform(renderer, affine)
         self.patch._path = tpath
-        self.patch.set_transform(affine)
-        self.patch.set_clip_box(gc._cliprect)
-        self.patch.set_clip_path(gc._clippath)
+        self.patch.set_transform(affine + self._offset_transform(renderer))
+        self.patch.set_clip_box(gc.get_clip_rectangle())
+        clip_path = gc.get_clip_path()
+        if clip_path:
+            self.patch.set_clip_path(*clip_path)
         self.patch.draw(renderer)
